@@ -28,6 +28,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */
 #include "gmutil.h"
 
 iDeclareType(GmCerts)
+iDeclareType(GmIdentity)
 iDeclareType(GmResponse)
 
 enum iGmCertFlag {
@@ -69,6 +70,7 @@ typedef void (*iGmRequestProgressFunc)(iGmRequest *, size_t current, size_t tota
 
 void                enableFilters_GmRequest     (iGmRequest *, iBool enable);
 void                setUrl_GmRequest            (iGmRequest *, const iString *url);
+void                setIdentity_GmRequest       (iGmRequest *, const iGmIdentity *id);
 void                setTitanData_GmRequest      (iGmRequest *, const iString *mime,
                                                  const iBlock *payload, const iString *token);
 void                setSendProgressFunc_GmRequest(iGmRequest *, iGmRequestProgressFunc func);
